# PyKoopman-AE

Python package PyKoopman-AE for the data-driven identification of the Koopman Operator-based models for dynamical systems using autoencoders.

## To Do
1. Deploy the python package.
2. Add documentation: Instructions for installation and usage.
